@@ -59,7 +59,7 @@ typedef struct denominator_list_s denominator_list_s;
 typedef denominator_list_s *denominator_list;
 
 struct denominator_list_s{number n; denominator_list next;};
-extern denominator_list DENOMINATOR_LIST;
+EXTERN_VAR denominator_list DENOMINATOR_LIST;
 
 class sTObject
 {
@@ -173,7 +173,7 @@ public:
 #endif
 };
 
-extern int strat_nr;
+EXTERN_VAR int strat_nr;
 
 class sLObject : public sTObject
 {
@@ -262,7 +262,7 @@ public:
 };
 
 
-extern int HCord;
+EXTERN_VAR int HCord;
 
 class skStrategy
 #ifdef HAVE_OMALLOC
@@ -365,6 +365,7 @@ public:
   #endif
   #ifdef HAVE_SHIFTBBA
   int cv; // in shift bases: counting V criterion
+  /*BOOLEAN*/ char rightGB;
   #endif
   /*BOOLEAN*/ char interpt;
   /*BOOLEAN*/ char homog;
@@ -600,6 +601,8 @@ int kFindDivisibleByInT(const kStrategy strat, const LObject* L, const int start
 int kFindDivisibleByInT_Z(const kStrategy strat, const LObject* L, const int start=0);
 int kFindSameLMInT_Z(const kStrategy strat, const LObject* L, const int start=0);
 
+/// tests if T[0] divides the leading monomial of L, returns -1 if not
+int kTestDivisibleByT0_Z(const kStrategy strat, const LObject* L);
 /// return -1 if no divisor is found
 ///        number of first divisor in S, otherwise
 int kFindDivisibleByInS(const kStrategy strat, int *max_ind, LObject* L);
@@ -849,28 +852,20 @@ poly pCopyL2p(LObject h, kStrategy strat);
 
 void enterTShift(LObject p, kStrategy strat, int atT = -1);
 
-void initBuchMoraShift (ideal F,ideal Q,kStrategy strat);
-
-void enterOnePairSelfShifts (poly qq, poly p, int ecart, int isFromQ, kStrategy strat, int atR);
-
 void enterOnePairShift (poly q, poly p, int ecart, int isFromQ, kStrategy strat, int atR, int ecartq, int qisFromQ, int shiftcount, int ifromS);
 
 void enterpairsShift (poly h,int k,int ecart,int pos,kStrategy strat, int atR);
 
-void updateSShift(kStrategy strat);
-
 void initBbaShift(kStrategy strat);
 
 poly redtailBbaShift (LObject* L, int pos, kStrategy strat, BOOLEAN withT, BOOLEAN normalize);
 
 int redFirstShift (LObject* h,kStrategy strat); // ok
 
-ideal freegb(ideal I);
-
 ideal bbaShift(ideal F, ideal Q,intvec *w,intvec *hilb,kStrategy strat);
 // test syz strategy: // will be removed soon
-extern  int (*test_PosInT)(const TSet T,const int tl,LObject &h);
-extern  int (*test_PosInL)(const LSet set, const int length,
+EXTERN_VAR int (*test_PosInT)(const TSet T,const int tl,LObject &h);
+EXTERN_VAR int (*test_PosInL)(const LSet set, const int length,
                 LObject* L,const kStrategy strat);
 
 static inline void kDeleteLcm(LObject *P)
