@@ -8,7 +8,6 @@
 */
 
 /* includes */
-#include "omalloc/omalloc.h"
 #include "misc/auxiliary.h"
 #include "coeffs/coeffs.h"
 #include "misc/intvec.h"
@@ -397,7 +396,7 @@ ring   rEnvelope(ring r);
 /// we must always have this test!
 static inline BOOLEAN rIsPluralRing(const ring r)
 {
-  assume(r != NULL); assume(r->cf != NULL);
+  assume(r != NULL);
 #ifdef HAVE_PLURAL
   nc_struct *n;
   return ((n=r->GetNC()) != NULL) /*&& (n->type != nc_error)*/;
@@ -406,16 +405,21 @@ static inline BOOLEAN rIsPluralRing(const ring r)
 #endif
 }
 
-static inline BOOLEAN rIsNCRing(const ring r)
+static inline BOOLEAN rIsLPRing(const ring r)
 {
-  assume(r != NULL); assume(r->cf != NULL);
-#ifdef HAVE_PLURAL
-  return (r->isLPring!=0) || rIsPluralRing(r);
+  assume(r != NULL);
+#ifdef HAVE_SHIFTBBA
+  return (r->isLPring!=0);
 #else
   return FALSE;
 #endif
 }
 
+static inline BOOLEAN rIsNCRing(const ring r)
+{
+  return rIsLPRing(r) || rIsPluralRing(r);
+}
+
 static inline BOOLEAN rIsRatGRing(const ring r)
 {
   assume(r != NULL);
@@ -543,7 +547,8 @@ static inline BOOLEAN rField_has_simple_inverse(const ring r)
 static inline BOOLEAN rField_has_simple_Alloc(const ring r)
 { assume(r != NULL); assume(r->cf != NULL); return nCoeff_has_simple_Alloc(r->cf); }
 
-n_coeffType rFieldType(const ring r);
+/// the type of the coefficient filed of r (n_Zp, n_Q, etc)
+static inline n_coeffType rFieldType(const ring r) { return (r->cf->type); }
 
 /// this needs to be called whenever a new ring is created: new fields
 /// in ring are created (like VarOffset), unless they already exist
@@ -732,7 +737,6 @@ ring   rAssure_CompLastBlock(const ring r, BOOLEAN complete = TRUE);
 /// makes sure that c/C ordering is last ordering and SyzIndex is first
 ring   rAssure_SyzComp_CompLastBlock(const ring r);
 ring   rAssure_TDeg(const ring r, int &pos);
-BOOLEAN rHasTDeg(const ring r);
 
 /// return the max-comonent wchich has syzIndex i
 /// Assume: i<= syzIndex_limit
@@ -821,5 +825,12 @@ int rTypeOfMatrixOrder(const intvec *order);
 
 void rDelete(ring r); // To be used instead of rKill!
 
-extern omBin sip_sring_bin;
+EXTERN_VAR omBin sip_sring_bin;
+
+// ring manipulation
+/// K[x],"y" -> K[x,y] resp. K[y,x]
+ring rPlusVar(const ring r, char *v,int left);
+
+/// undo rPlusVar
+ring rMinusVar(const ring r, char *v);
 #endif
